--[[
--------------------- PLUGIN GENERATEUR REMOTE DMX AKWARIOM -------------
--------------------------------------------------------------------------
Permet de créer les remotes dmx nécessaires pour le fonctionnement du KONTROL2 AKWARIOM.

- Lancer le plugin.
- Une fenêtre d'infos affiche les différents modes disponibles.
- Saisir dans le popup qui s'affiche le numéro de mode choisi (1 à 6).

DESIGNATION DES MODES :
	MODE 1 : Création des remotes pour le contrôle des Fader GMA2 1 à 15
	MODE 2 : Création des remotes pour le contrôle des Fader GMA2 16 à 30
	MODE 3 : Création des remotes pour le contrôle des Fader GMA2 31 à 45
	MODE 4 : Création des remotes pour le contrôle des Fader GMA2 46 à 60
	MODE 5 : Création des remotes pour le contrôle des Fader GMA2 61 à 75
	MODE 6 : Création des remotes pour le contrôle des Fader GMA2 76 à 90

Le KONTROL2 AKWARIOM est opérationnel.
--------------------------------------------------
NOTE :
Le Fader 16 du KONTROL2 contrôle par défaut le Grand Master.
Le plugin assigne et fixe automatiquement le Grand Master à l'exécuteur Fader 90.
-------------------------------------------------------------------------
- Création William BELLEUDY pour AKWARIOM - Janvier 2016 - GMA2 V 3.2.1.0
- Amélioration William BELLEUDY pour AKWARIOM - Janvier 2017 - GMA2 V 3.2.2.16
-------------------------------------------------------------------------
--]]
--------------------------------------------------
-- DEFINITION DES VARIABLES LOCALES / RACCOURCIS
--------------------------------------------------
local speed = 0.01
local sleep = gma.sleep; 
local cmd   = gma.cmd;
local input = gma.textinput;
local fbk   = gma.feedback;
local Confirmer = gma.gui.confirm;

local Akwariom, CleanUp;
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
Akwariom = function()
	::Debut::
	
	Confirmer('DESIGNATION DES MODES !','MODE 1 : Création remotes dmx 1 à 15 \n MODE 2 : Création remotes dmx 16 à 30 \n MODE 3 : Création remotes dmx 31 à 45 \n MODE 4 : Création remotes dmx 46 à 60 \n MODE 5 : Création remotes dmx 61 à 75 \n MODE 6 : Création remotes dmx 76 à 90');
	
	local Mode = input('Numéro Mode ? 1 à 6','');
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 1 : AKWARIOM DMX 1 - 15
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	if tonumber(Mode) == 1 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 1
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 15"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 1
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 15"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 1
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 15"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 1
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 15"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 101
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 115"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 1-15','Le remote Akwariom a été créé avec succès !')
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 2 : AKWARIOM DMX 16 - 30
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	elseif tonumber(Mode) == 2 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 16
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 30"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 16
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 30"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 16
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 30"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 16
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 30"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 116
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 130"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 16-30','Le remote Akwariom a été créé avec succès !')
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 3 : AKWARIOM DMX 31 - 45
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	elseif tonumber(Mode) == 3 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 31
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 45"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 31
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 45"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 31
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 45"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 31
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 45"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 131
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 145"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 31-45','Le remote Akwariom a été créé avec succès !')
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 4 : AKWARIOM DMX 46 - 60
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	elseif tonumber(Mode) == 4 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 46
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 60"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 46
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 60"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 46
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 60"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 46
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 60"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 146
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 160"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 46-60','Le remote Akwariom a été créé avec succès !')
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 5 : AKWARIOM DMX 61 - 75
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	elseif tonumber(Mode) == 5 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 61
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 75"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 61
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 75"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 61
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 75"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 61
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 75"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 161
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 175"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 61-75','Le remote Akwariom a été créé avec succès !')
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- MODE 6 : AKWARIOM DMX 76 - 90
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
	elseif tonumber(Mode) == 6 then
		--------------------------------------------------
		-- CHANGE DESTINATION REMOTE MIDI ET CREATION
		--------------------------------------------------
		cmd('Assign Remote "DmxRemotes" /enabled=1');
		cmd('CD REMOTETYPES');
		cmd('ChangeDest DMXREMOTES');
		cmd('Store 1 Thru 80');
		cmd('Label 1 Thru 80 "AKWARIOM 1"');
		--------------------------------------------------
		-- GESTION FADER
		--------------------------------------------------
		local Compteur = 1
		local CompteurExec = 76
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=fader /info="Fader : '..CompteurExec..' sur 90"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 3 - HAUT
		--------------------------------------------------
		local Compteur = 16
		local CompteurExec = 76
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=2 /info="Bouton 3 : '..CompteurExec..' sur 90"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 2 - MID
		--------------------------------------------------
		local Compteur = 31
		local CompteurExec = 76
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=1 /info="Bouton 2 : '..CompteurExec..' sur 90"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION BOUTON 1 - BAS
		--------------------------------------------------
		local Compteur = 46
		local CompteurExec = 76
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Bouton 1 : '..CompteurExec..' sur 90"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION EXECUTEUR BOUTON
		--------------------------------------------------
		local Compteur = 61
		local CompteurExec = 176
		
		for i = 1 , 15 , 1 do
			cmd('Assign '..Compteur..' /Dmx=10.'..Compteur..' /Type=Exec /Page=Current /Executor='..CompteurExec..' /Button=0 /info="Exec Btn : '..CompteurExec..' sur 190"');
			Compteur = Compteur +1
			CompteurExec = CompteurExec +1
			sleep(speed);
		end
		--------------------------------------------------
		-- GESTION PAGE FADER +/- ET PAGE BOUTON +/-
		--------------------------------------------------
		cmd('Assign 76 /Dmx=10.076 /Type=Hardkey /Keycode=PAGE_FADER_UP /info="Page Fader Suivante"');
		cmd('Assign 77 /Dmx=10.077 /Type=Hardkey /Keycode=PAGE_FADER_DOWN /info="Page Fader Précédente"');
		cmd('Assign 78 /Dmx=10.078 /Type=Hardkey /Keycode=PAGE_BUTTON_UP /info="Page Bouton Suivante"');
		cmd('Assign 79 /Dmx=10.079 /Type=Hardkey /Keycode=PAGE_BUTTON_DOWN /info="Page Bouton Précédente"');
		cmd('Assign 80 /Dmx=10.080 /Type=Exec /Page=1 /Executor=90 /Button=fader /info="Grand Master"');
		--------------------------------------------------
		-- ASSIGNATION DU GRAND MASTER
		--------------------------------------------------
		cmd('Assign SpecialMaster 2.1 At Executor 90');
		cmd('Fix Executor 90');
		
		Confirmer('AKWARIOM DMX 76-90','Le remote Akwariom a été créé avec succès !')
	else
		if Confirmer('MODE NON VALIDE !','Le mode choisi est incorrect ! \n Modes possibles : 1 à 6.') then
			goto Debut
		else
			fbk('---------------------------------------------------------');
			fbk("- Plugin AKWARIOM DMX : Opération annulée par l'utilisateur !");
			fbk('---------------------------------------------------------');
		end
	end
end
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
-- NETTOYAGE
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
CleanUp = function()
	cmd('CD /');
end	
return Akwariom, CleanUp;
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
--XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX